==> humhub-1.6.4.tar.gz: humhub-1.6.4/protected/humhub/modules/activity/messages/es/base.php <==
<?php
return array (
  '{displayName} created the new space {spaceName}' => '{displayName} creó un nuevo espacio: {spaceName}',
  '{displayName} created this space.' => '{displayName} creó este espacio.',
  '{displayName} joined the space {spaceName}' => '{displayName} se unió al espacio {spaceName}',
  '{displayName} joined this space.' => '{displayName} se unió a este espacio.',
  '{displayName} left the space {spaceName}' => '{displayName} dejó el espacio {spaceName}',
  '{displayName} left this space.' => '{displayName} dejó este espacio.',
  '{spaceName} has been archived' => 'Se ha archivado {spaceName}',
  '{spaceName} has been unarchived' => 'Se ha sacado del archivo {spaceName}',
  '<strong>E-Mail</strong> Summaries' => '<strong>Resúmenes</strong> de Correo',
  '<strong>Latest</strong> activities' => '<strong>Últimas</strong> actividades',
  'Activities' => 'Actividades',
  'Daily' => 'Diario',
  'E-Mail Summaries' => 'Resúmenes de Correo',
  'E-Mail summaries are sent to inform you about recent activities in the network.' => 'Resúmenes de correo son enviados para informarte acerca de actividades recientes en la red.',
  'E-Mail summaries are sent to users to inform them about recent activities in your network.' => 'Resúmenes de correo son enviados a los usuarios para informarles acerca de actividades recientes en la red.',
  'Exclude spaces below from the mail summary' => 'Excluir estos espacios del Resumen de Correo',
  'Hourly' => 'Por hora',
  'Interval' => 'Intervalo',
  'Latest news' => 'Últimas noticias',
  'Never' => 'Nunca',
  'On this page you can configure the contents and the interval of these e-mail updates.' => 'En esta página puedes configurar los contenidos y el intervalo de estos correos de actualizaciones.',
  'On this page you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'En esta página puedes definir el comportamiento de tus usuarios. Estos ajustes pueden ser sobreescritos por los usuarios en la página de ajustes de su cuenta.',
  'Only include spaces below to the mail summary' => 'Incluir solo estos espacios en el correo de resumen',
  'Reset to defaults' => 'Restablecer los valores predeterminados',
  'See online:' => 'Ver en línea:',
  'Spaces' => 'Espacios',
  'There are no activities yet.' => 'No hay actividades todavia.',
  'Weekly' => 'Semanal',
  'You will only receive an e-mail if there is something new.' => 'Solamente recibirás un correo si hay algo nuevo.',
  'Your daily summary' => 'Tu resumen diario',
  'Your weekly summary' => 'Su resumen semanal',
  'see online' => 'ver en línea',
  'via' => 'en',
  '{user1} now follows {user2}.' => '{user1} ahora sigue a {user2}.',
);

==> humhub-1.13.1.tar.gz: humhub-1.13.1/protected/humhub/modules/activity/messages/es/base.php <==
<?php
return array (
  '<strong>E-Mail</strong> Summaries' => '<strong>Resúmenes</strong> de Correo',
  '<strong>Latest</strong> activities' => '<strong>Últimas</strong> actividades',
  'Activities' => 'Actividades',
  'Daily' => 'Diario',
  'E-Mail Summaries' => 'Resúmenes por Correo electrónico',
  'E-Mail summaries are sent to inform you about recent activities in the network.' => 'Resúmenes de correo son enviados para informarte acerca de actividades recientes en la red.',
  'E-Mail summaries are sent to users to inform them about recent activities in your network.' => 'Resúmenes de correo son enviados a los usuarios para informarles acerca de actividades recientes en la red.',
  'Exclude spaces below from the mail summary' => 'Excluir los espacios a continuación del resumen por correo',
  'Hourly' => 'Por hora',
  'Interval' => 'Intervalo',
  'Latest news' => 'Últimas noticias',
  'Never' => 'Nunca',
  'On this page you can configure the contents and the interval of these e-mail updates.' => 'En esta página puedes configurar los contenidos y el intervalo de estos correos de actualizaciones.',
  'On this page you can define the default behavior for your users. These settings can be overwritten by users in their account settings page.' => 'En esta página puedes definir el comportamiento de tus usuarios. Estos ajustes pueden ser sobreescritos por los usuarios en la página de ajustes de su cuenta.',
  'Only include spaces below to the mail summary' => 'Incluir solo estos espacios en el correo de resumen',
  'Reset to defaults' => 'Restablecer los valores predeterminados',
  'See online:' => 'Ver en línea:',
  'Spaces' => 'Espacios',
  'There are no activities yet.' => 'No hay actividades todavia.',
  'Weekly' => 'Semanal',
  'You will only receive an e-mail if there is something new.' => 'Solamente recibirás un correo si hay algo nuevo.',
  'Your daily summary' => 'Tu resumen diario',
  'Your weekly summary' => 'Tu resumen semanal',
  'see online' => 'ver en línea',
  'via' => 'en',
  '{displayName} created the new space {spaceName}' => '{displayName} creó un nuevo espacio: {spaceName}',
  '{displayName} created this space.' => '{displayName} creó este espacio.',
  '{displayName} joined the space {spaceName}' => '{displayName} se unió al espacio {spaceName}',
  '{displayName} joined this space.' => '{displayName} se unió a este espacio.',
  '{displayName} left the space {spaceName}' => '{displayName} dejó el espacio {spaceName}',
  '{displayName} left this space.' => '{displayName} dejó este espacio.',
  '{spaceName} has been archived' => 'Se ha archivado {spaceName}',
  '{spaceName} has been unarchived' => 'Se ha sacado del archivo {spaceName}',
  '{user1} now follows {user2}.' => '{user1} ahora sigue a {user2}.',
);
